__title__ = 'iflowly'
__description__ = 'IFlowly Pythonn SDK.'
__url__ = 'https://github.com/Iflowly/python-iflowly-sdk'
__version__ = '0.0.2'
__author__ = 'IFlowly'
__author_email__ = 'mohammad.albakri@iflowly.com'
__license__ = 'MIT License'
__copyright__ = 'Copyright 2021 Mohammad Albakri'
__cake__ = u'\u2728 \U0001f370 \u2728'
